@@ -32,6 +32,4 @@ def run_o(lines, file, output):
             cmd = "python " + file_run
             import subprocess
             s = subprocess.check_output(cmd, shell=True)
-            # s,ok = execute_command(cmd.split(), shell=True)
-            print(s)
             os.remove(file_run)
\ No newline at end of file
