@@ -27,7 +27,8 @@ def censor_code(lines, keep=True):
     return lines
 
 
-def censor_file(file, run_files=True, run_out_dirs=None, cut_files=True, solution_list=None,
+def censor_file(file, run_files=True, run_out_dirs=None, cut_files=True,
+                output_solution=False,
                 censor_files=True,
                 base_path=None,
                 strict=True,
@@ -37,6 +38,7 @@ def censor_file(file, run_files=True, run_out_dirs=None, cut_files=True, solutio
     if references == None:
         references = {}
 
+    cut = []
     dbug = False
     with open(file, 'r', encoding='utf8') as f:
         s = f.read()
@@ -69,31 +71,13 @@ def censor_file(file, run_files=True, run_out_dirs=None, cut_files=True, solutio
 
         if censor_files:
             lines = fix_f(lines, dbug)
+            if "pacman" in str(file):
+                print("sdaf")
             lines, nB, cut = fix_b(lines)
         else:
             nB = 0
         lines = fix_r(lines)
 
-        # if censor_files and len(cut) > 0 and solution_list is not None:
-        #     # fname = file.__str__()
-        #     # i = fname.find("irlc")
-        #     # wk = fname[i+5:fname.find("\\", i+6)]
-        #     # sp = paths['02450students'] +"/solutions/"
-        #     # if not os.path.exists(sp):
-        #     #     os.mkdir(sp)
-        #     # sp = sp + wk
-        #     # if not os.path.exists(sp):
-        #     #     os.mkdir(sp)
-        #     sols = []
-        #     stext = ["\n".join(lines) for lines in cut]
-        #     # for i,sol in enumerate(stext):
-        #     #     # sols.append( (sol,) )
-        #     #     # sout = sp + f"/{os.path.basename(fname)[:-3]}_TODO_{i+1}.py"
-        #     #     # wsol = any([True for s in solution_list if os.path.basename(sout).startswith(s)])
-        #     #     # print(sout, "(published)" if wsol else "")
-        #     #     # if wsol:
-        #     #     #     with open(sout, "w") as f:
-        #     #     #         f.write(sol)
 
         if len(lines) > 0 and len(lines[-1])>0:
             lines.append("")
@@ -104,7 +88,7 @@ def censor_file(file, run_files=True, run_out_dirs=None, cut_files=True, solutio
 
     with open(file, 'w', encoding='utf-8') as f:
         f.write(s2)
-    return nB
+    return nB, cut
 
 
 def fix_copyright(s, license_head):
